/*
 * Copyright (c) 2002-2007, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.mylutece.service;

import fr.paris.lutece.plugins.mylutece.business.IExternalApplication;

import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


public class ExternalApplicationServiceImpl implements IExternalApplicationService
{
    private static final IExternalApplicationService _instance = new ExternalApplicationServiceImpl(  );
    private Map<String, IExternalApplication> _applicationMap;

    private ExternalApplicationServiceImpl(  )
    {
        _applicationMap = new HashMap<String, IExternalApplication>(  );
    }

    public static IExternalApplicationService getInstance(  )
    {
        return _instance;
    }

    public IExternalApplication getApplicationByName( String strName )
    {
        return _applicationMap.get( strName );
    }

    public Collection<IExternalApplication> getAvailableApplications(  )
    {
        return _applicationMap.values(  );
    }

    public void setApplication( IExternalApplication application )
    {
        _applicationMap.put( application.getName(  ), application );
    }

    public void setApplications( List<IExternalApplication> applications )
    {
        for ( IExternalApplication application : applications )
        {
            setApplication( application );
        }
    }

    public boolean applicationsExists(  )
    {
        Collection<IExternalApplication> allApplication = getAvailableApplications(  );

        if ( ( allApplication == null ) || allApplication.isEmpty(  ) )
        {
            return false;
        }

        return true;
    }
}
